***************************************
Questions, Issues and Feature Requests
***************************************

All bugs and feature requests are tracked in GitHub Issues.
Before raising an issue, please check the following: 

 - Your issue is not being currently addressed by other issues or pull requests.
 - Make sure you raise the appropriate issue type and fill out the form per the instructions.
 - All code snippets and error messages are formatted in appropriate code blocks.
 - Whenever possible include reproducible examples (data + code) and if an exception is raised, please provide the traceback.

